summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneywizard.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit902ba103f2215bcefa22d62b1c9138aa4b88891c (patch)
tree63ef88424b9be33a31e5a8de61343fb8d7633937 /kmymoney2/widgets/kmymoneywizard.h
parent7e51b6d5ddc01fc3bc69f30bc5d3933a7709dbf2 (diff)
downloadkmymoney-902ba103f2215bcefa22d62b1c9138aa4b88891c.tar.gz
kmymoney-902ba103f2215bcefa22d62b1c9138aa4b88891c.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kmymoney@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmymoney2/widgets/kmymoneywizard.h')
-rw-r--r--kmymoney2/widgets/kmymoneywizard.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/kmymoney2/widgets/kmymoneywizard.h b/kmymoney2/widgets/kmymoneywizard.h
index 88d8530..803061e 100644
--- a/kmymoney2/widgets/kmymoneywizard.h
+++ b/kmymoney2/widgets/kmymoneywizard.h
@@ -70,7 +70,7 @@ class kMandatoryFieldGroup;
* class KNewUserPage : public KMyMoneyWizardPage
* {
* public:
- * KNewUserPage(unsigned int step, TQWidget* widget, KNewUserWizard* tqparent, const char* name);
+ * KNewUserPage(unsigned int step, TQWidget* widget, KNewUserWizard* parent, const char* name);
*
* protected:
* KNewUserWizard* m_wizard;
@@ -80,9 +80,9 @@ class kMandatoryFieldGroup;
* The implementation of this class is rather straight-forward:
*
* @code
* KNewUserPage::KNewUserPage(unsigned int step, TQWidget* widget, KNewUserWizard* tqparent, const char* name) :
* KMyMoneyWizardPage(step, widget, name),
- * m_wizard(tqparent)
+ * m_wizard(parent)
* {
* }
* @endcode
@@ -102,7 +102,7 @@ class kMandatoryFieldGroup;
* Q_OBJECT
TQ_OBJECT
* public:
- * KNewUserGeneral(KNewUserWizard* tqparent, const char* name = 0);
+ * KNewUserGeneral(KNewUserWizard* parent, const char* name = 0);
* KMyMoneyWizardPage* nextPage(void);
* bool isLastPage(void) { return false; }
*
@@ -115,9 +115,9 @@ class kMandatoryFieldGroup;
* fill some widgets, it could be as simple as:
*
* @code
* KNewUserGeneral::KNewUserGeneral(KNewUserWizard* tqparent, const char* name) :
* KNewUserGeneralDecl(tqparent),
* KNewUserPage(1, this, tqparent, name)
* {
* kMandatoryFieldGroup* mandatoryGroup = new kMandatoryFieldGroup(this);
* mandatoryGroup->add(m_userName);
@@ -270,10 +270,10 @@ template <class T>
class WizardPage : public KMyMoneyWizardPage
{
public:
- WizardPage(unsigned int step, TQWidget* widget, T* tqparent, const char* name) :
+ WizardPage(unsigned int step, TQWidget* widget, T* parent, const char* name) :
KMyMoneyWizardPage(step, widget, name),
- m_wizard(tqparent),
- m_wizardBase(tqparent)
+ m_wizard(parent),
+ m_wizardBase(parent)
{
}
virtual ~WizardPage() {}
@@ -337,7 +337,7 @@ protected:
* Q_OBJECT
TQ_OBJECT
* public:
- * KNewUserWizard(TQWidget* tqparent = 0, const char* name = 0, bool modal = false, WFlags flags = 0);
+ * KNewUserWizard(TQWidget* parent = 0, const char* name = 0, bool modal = false, WFlags flags = 0);
*
* private:
* KNewUserGeneral* m_generalPage;
@@ -355,8 +355,8 @@ protected:
* The implementation is also easy and looks like this:
*
* @code
* KNewUserWizard::KNewUserWizard(TQWidget* tqparent, const char* name, bool modal, WFlags flags) :
* KMyMoneyWizard(tqparent, name, modal, flags)
* {
* setTitle("KMyMoney New User Setup");
* addStep("General Data");
@@ -450,7 +450,7 @@ protected:
/**
* Constructor (kept protected, so that one cannot create such an object directly)
*/
- KMyMoneyWizard(TQWidget *tqparent = 0, const char *name = 0, bool modal = false, WFlags f = 0);
+ KMyMoneyWizard(TQWidget *parent = 0, const char *name = 0, bool modal = false, WFlags f = 0);
/**
* This method sets up the first page after creation of the object
@@ -80,9 +80,9 @@ class kMandatoryFieldGroup;
*
* @code
- * KNewUserPage::KNewUserPage(unsigned int step, TQWidget* widget, KNewUserWizard* tqparent, const char* name) :
+ * KNewUserPage::KNewUserPage(unsigned int step, TQWidget* widget, KNewUserWizard* parent, const char* name) :
* KMyMoneyWizardPage(step, widget, name),
@@ -115,9 +115,9 @@ class kMandatoryFieldGroup;
*
* @code
- * KNewUserGeneral::KNewUserGeneral(KNewUserWizard* tqparent, const char* name) :
- * KNewUserGeneralDecl(tqparent),
- * KNewUserPage(1, this, tqparent, name)
+ * KNewUserGeneral::KNewUserGeneral(KNewUserWizard* parent, const char* name) :
+ * KNewUserGeneralDecl(parent),
+ * KNewUserPage(1, this, parent, name)
* {
* kMandatoryFieldGroup* mandatoryGroup = new kMandatoryFieldGroup(this);
@@ -355,8 +355,8 @@ protected:
*
* @code
- * KNewUserWizard::KNewUserWizard(TQWidget* tqparent, const char* name, bool modal, WFlags flags) :
- * KMyMoneyWizard(tqparent, name, modal, flags)
+ * KNewUserWizard::KNewUserWizard(TQWidget* parent, const char* name, bool modal, WFlags flags) :
+ * KMyMoneyWizard(parent, name, modal, flags)
* {
* setTitle("KMyMoney New User Setup");